@@ -40,6 +40,7 @@ which are easily ignored with a custom ``convert()`` function.
 * If an option doesn't use a metavar it is made True if it exists, False otherwise.
 """
 
+import warnings
 import getopt
 import logging
 import sys
@@ -537,7 +538,21 @@ class LoggingCmd(Cmd):
             else:
                 logging.basicConfig(level=logging.INFO, format=format)
 
-def handle_command(commands, cmd_line_parts=None, program=None, service=None, cmd=None):
+def print_fn(string, *args, **opts):
+    if opts.get('end') is None:
+        end = '\n'
+    else:
+        end = opts.get('end')
+    res = (string + end) % args
+    print res
+
+# Tip: If you add new arguments here, make sure you add them to the nested handle_command() call below too.
+def handle_command(commands, cmd_line_parts=None, program=None, service=None, cmd=None, out=print_fn, err=print_fn):
+    if service is not None: 
+        warnings.warn(
+            'The \'service\' argument is deprecated, please change your '
+            'commands to be classes with simplified \'on_run()\' methods'
+        )
     # Prepare the cmd object to have the args and opts set
     if cmd is None:
         cmd = AttributeDict(
@@ -558,6 +573,8 @@ def handle_command(commands, cmd_line_parts=None, program=None, service=None, cm
         cmd['raw_opts'] = None
         cmd['instance'] = None
         cmd['service']=service
+    cmd['out'] = out
+    cmd['err'] = err
     if program is None:
         program = sys.argv[0]
         if os.sep in sys.argv[0]:
@@ -615,7 +632,15 @@ def handle_command(commands, cmd_line_parts=None, program=None, service=None, cm
             sub_command = None
             raise getopt.GetoptError(error)
         if isinstance(commands[sub_command], dict):
-            return handle_command(commands[sub_command], cmd_line_parts=args, program='%s %s'%(program, sub_command), service=service, cmd=cmd)
+            return handle_command(
+                commands[sub_command], 
+                cmd_line_parts=args,
+                program='%s %s'%(program, sub_command), 
+                service=service, 
+                cmd=cmd,
+                err=err, 
+                out=out,
+            )
         sub_args, sub_opts = process_command(
             args,#new_cmd_line_parts, 
             sub_command, 
